'use strict';
const vscode = require("vscode");
class CustomPattern {
    constructor(pattern, foreground, background, fontWeight, fontStyle, border, borderRadius, borderSpacing, letterSpacing, overviewRulerColor, overviewRulerLane, textDecoration) {
        this.pattern = pattern;
        this.foreground = foreground;
        this.background = background;
        this.regexes = this.createRegex(pattern);
        this.decoration = vscode.window.createTextEditorDecorationType({
            backgroundColor: this.background,
            color: this.foreground,
            fontWeight: fontWeight,
            fontStyle: fontStyle,
            border: border,
            borderRadius: borderRadius,
            letterSpacing: letterSpacing,
            overviewRulerColor: overviewRulerColor,
            overviewRulerLane: overviewRulerLane,
            textDecoration: textDecoration,
            rangeBehavior: vscode.DecorationRangeBehavior.ClosedClosed
        });
    }
    dispose() {
        this.decoration.dispose();
    }
    createRegex(pattern) {
        const result = [];
        // Check if the log level value is a "simple" string or not.
        if (!/^\w+$/g.test(pattern)) {
            // log level is already regex.
            try {
                result.push(new RegExp(pattern, 'gm'));
            }
            catch (err) {
                vscode.window.showErrorMessage('Regex of custom log level is invalid. Error: ' + err);
            }
        }
        else {
            // Log level consists only of "simple" characters -> build regex.
            const first = new RegExp('\\b(?!\\[)(' + pattern.toUpperCase() +
                '|' + pattern + ')(?!\\]|\\:)\\b', 'gm');
            const second = new RegExp('\\[(' + pattern + ')\\]|\\b(' + pattern + ')\\:', 'ig');
            result.push(first, second);
        }
        return result;
    }
}
module.exports = CustomPattern;
//# sourceMappingURL=CustomPattern.js.map