'use strict';
const jasmine = require("jasmine");
const path = require("path");
const util = require("util");
class TestRunner {
    run(configPath, clb) {
        const runner = new jasmine(null);
        runner.projectBaseDir = path.dirname(configPath);
        runner.configureDefaultReporter({
            print() {
                const line = util.format.apply(util.format, arguments);
                if (line !== '\n') {
                    console.log(line);
                }
            }
        });
        runner.loadConfigFile(configPath);
        runner.loadSpecs();
        runner.loadHelpers();
        runner.onComplete((passed) => {
            if (passed) {
                clb(null);
            }
            else {
                clb(new Error('At least one test failed.'));
            }
        });
        runner.execute();
    }
}
// Executed directly
if (!module.parent) {
    if (process.argv.indexOf('-c') === -1) {
        process.stdout.write('The "-c" argument is required. (Path to the jasmine config file)');
        process.exit(1);
    }
    else if (process.argv.length !== 4) {
        process.stdout.write('The argument is missing. Example to start the test: \
        "node testRunner.js -c ./myConfigPath/jasmine.json"');
        process.exit(1);
    }
    else {
        let configPath = process.argv[process.argv.indexOf('-c') + 1];
        if (!path.isAbsolute(configPath)) {
            configPath = path.resolve(configPath);
        }
        const runner = new TestRunner();
        runner.run(configPath, (error) => {
            if (error) {
                console.log(error.message);
            }
            else {
                console.log('All tests succeeded.');
            }
        });
    }
}
module.exports = TestRunner;
//# sourceMappingURL=testRunner.js.map